==> cramr_ui_lib-0.0.10.tar.gz: test/routes/verb_indicative_study_flashcard_mode_form_state_test.dart <==
import 'package:cramr_ui_lib/model/study_mode.dart';
import 'package:cramr_ui_lib/model/study_mode_state.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_flashcard_mode_route.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'aime',
  'aimes',
  'aime',
  'aimons',
  'aimez',
  'aiment',
];

final List<String> _randomPronouns = [
  'je',
  'tu',
  'il/elle',
  'nous',
  'vous',
  'ils/elles',
];

const String _randomInfinitive = 'infinitive';
final Finder sliderFinder = find.byKey(Key('flashcard_slider'));
final Finder playButtonFinder = find.byKey(const Key('PlayButton'));
final Finder resetButtonFinder = find.byKey(const Key('ResetButton'));

void main() {
  testWidgets('Test the flashcard mode study screen',
      (WidgetTester tester) async {
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(create: (BuildContext context) {
            var model = VerbTestModel();
            model.initialise(_randomIndicative, _randomPronouns, 'fr',
                _randomInfinitive, 'translation');
            return model;
          }),
          ChangeNotifierProvider(create: (BuildContext context) {
            return StudyModeState(StudyMode.flashCardMode);
          })
        ],
        child: VerbIndicativeStudyFlashcardModeRoute(
          key: UniqueKey(),
        )));
    final Finder translationFinder = find.text("translation");
    expect(translationFinder, findsOneWidget);
    Finder findFirstIndicative = find.text(_randomIndicative[0]);
    expect(findFirstIndicative, findsWidgets);
    expect(sliderFinder, findsOneWidget);
    expect(playButtonFinder, findsOneWidget);
    expect(resetButtonFinder, findsNothing);
    await tester.tapAt(Offset(tester.getCenter(sliderFinder).dx - 70,
        tester.getCenter(sliderFinder).dy));
    await tester.pumpAndSettle();
    expect(playButtonFinder, findsOneWidget);
    await tester.tap(playButtonFinder);
    await tester.pumpAndSettle(const Duration(seconds: 6));
    expect(resetButtonFinder, findsOneWidget);
    await tester.tap(resetButtonFinder);
    await tester.pumpAndSettle();
    expect(playButtonFinder, findsOneWidget);
    await tester.tap(playButtonFinder);
    await tester.pumpAndSettle(const Duration(seconds: 3));
    expect(resetButtonFinder, findsOneWidget);
    await tester.tap(resetButtonFinder);
    await tester.pumpAndSettle();
    expect(playButtonFinder, findsOneWidget);
    await tester.tap(playButtonFinder);
    await tester.pumpAndSettle(const Duration(seconds: 6));
  });
}

==> cramr_ui_lib-0.0.12.tar.gz: test/routes/verb_indicative_study_flashcard_mode_form_state_test.dart <==
import 'package:cramr_ui_lib/model/study_mode.dart';
import 'package:cramr_ui_lib/model/study_mode_state.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_flashcard_mode_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'aime',
  'aimes',
  'aime',
  'aimons',
  'aimez',
  'aiment',
];

final List<String> _randomPronouns = [
  'je',
  'tu',
  'il/elle',
  'nous',
  'vous',
  'ils/elles',
];

const String _randomInfinitive = 'infinitive';
final Finder sliderFinder = find.byKey(const Key('flashcard_slider'));
final Finder playButtonFinder = find.byKey(const Key('PlayButton'));
final Finder resetButtonFinder = find.byKey(const Key('ResetButton'));

void main() {
  testWidgets('Test the flashcard mode study screen',
      (WidgetTester tester) async {
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(create: (BuildContext context) {
            var model = VerbTestModel();
            model.initialise(_randomIndicative, _randomPronouns, 'fr',
                _randomInfinitive, 'translation');
            return model;
          }),
          ChangeNotifierProvider(create: (BuildContext context) {
            return StudyModeState(StudyMode.flashCardMode);
          })
        ],
        child: VerbIndicativeStudyFlashcardModeRoute(
          SettingsController(SettingsService(), ThemeMode.dark),
          key: UniqueKey(),
        )));
    final Finder translationFinder = find.text("translation");
    expect(translationFinder, findsOneWidget);
    Finder findFirstIndicative = find.text(_randomIndicative[0]);
    expect(findFirstIndicative, findsWidgets);
    expect(sliderFinder, findsOneWidget);
    expect(playButtonFinder, findsOneWidget);
    expect(resetButtonFinder, findsNothing);
    await tester.tapAt(Offset(tester.getCenter(sliderFinder).dx - 70,
        tester.getCenter(sliderFinder).dy));
    await tester.pumpAndSettle();
    expect(playButtonFinder, findsOneWidget);
    await tester.tap(playButtonFinder);
    await tester.pumpAndSettle(const Duration(seconds: 6));
    expect(resetButtonFinder, findsOneWidget);
    await tester.tap(resetButtonFinder);
    await tester.pumpAndSettle();
    expect(playButtonFinder, findsOneWidget);
    await tester.tap(playButtonFinder);
    await tester.pumpAndSettle(const Duration(seconds: 3));
    expect(resetButtonFinder, findsOneWidget);
    await tester.tap(resetButtonFinder);
    await tester.pumpAndSettle();
    expect(playButtonFinder, findsOneWidget);
    await tester.tap(playButtonFinder);
    await tester.pumpAndSettle(const Duration(seconds: 6));
  });
}
